import argparse
import logging
import time
from logging.handlers import TimedRotatingFileHandler

import tornado.ioloop
import tornado.log
import tornado.options
import tornado.web

import ai_callback_add_creative_handler
import ai_callback_add_group_handler
import ai_strategy_request_handler


def create_application():
    # 日志的格式
    log_formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s',
                                      '%m/%d/%Y %I:%M:%S %p')

    # ai策略请求解析的日志对象-----------------------------------------------------------
    ai_strategy_request_log_handler = TimedRotatingFileHandler("logs/add_group_log/ai_strategy_request.log",
                                                   when="midnight",
                                                   backupCount=100)

    ai_strategy_request_log_handler.setFormatter(log_formatter)
    ai_strategy_request_logger = logging.getLogger('ai_strategy_request_logger')
    ai_strategy_request_logger.addHandler(ai_strategy_request_log_handler)
    ai_strategy_request_logger.setLevel(logging.DEBUG)

    print("ai_strategy_request_logger's id is {}".format(id(ai_strategy_request_logger)))
    msg = "ai strategy request service started at {t}".\
           format(t=time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))
    ai_strategy_request_logger.info(msg)

    # 创建广告组回调日志对象-----------------------------------------------------------
    ai_callback_add_group_log_handler = TimedRotatingFileHandler("logs/add_group_log/ai_callback_add_group.log",
                                                               when="midnight",
                                                               backupCount=100)

    ai_callback_add_group_log_handler.setFormatter(log_formatter)
    ai_callback_add_group_logger = logging.getLogger('ai_callback_add_group_logger')
    ai_callback_add_group_logger.addHandler(ai_callback_add_group_log_handler)
    ai_callback_add_group_logger.setLevel(logging.DEBUG)

    print("ai_callback_add_group_logger's id is {}".format(id(ai_callback_add_group_logger)))
    msg = "ai callback add group logger service started at {t}". \
        format(t=time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))
    ai_callback_add_group_logger.info(msg)

    # 创建广告创意回调日志对象-----------------------------------------------------------
    ai_callback_add_creative_log_handler = TimedRotatingFileHandler("logs/add_group_log/ai_callback_add_creative.log",
                                                                 when="midnight",
                                                                 backupCount=100)

    ai_callback_add_creative_log_handler.setFormatter(log_formatter)
    ai_callback_add_creative_logger = logging.getLogger('ai_callback_add_creative_logger')
    ai_callback_add_creative_logger.addHandler(ai_callback_add_creative_log_handler)
    ai_callback_add_creative_logger.setLevel(logging.DEBUG)

    print("ai_callback_add_creative_logger's id is {}".format(id(ai_callback_add_creative_logger)))
    msg = "ai callback add creative logger service started at {t}". \
        format(t=time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))
    ai_callback_add_creative_logger.info(msg)

    web_application = tornado.web.Application([
        (r"/ai_strategy_request",
         ai_strategy_request_handler.AiStrategyRequestParse,
         {"logger": ai_strategy_request_logger}),
        (r"/ai_callback_add_group",
         ai_callback_add_group_handler.AiCallBackAddGroup,
         {"logger": ai_callback_add_group_logger}),
        (r"/ai_callback_add_creative",
         ai_callback_add_creative_handler.AiCallBackAddCreative,
         {"logger": ai_callback_add_creative_logger}),
    ])

    return web_application


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument('-p', '--port', type=int, default=31012)
    args = parser.parse_args()
    application = create_application()
    application.listen(args.port)
    tornado.ioloop.IOLoop.instance().start()
